aboutsummaryrefslogtreecommitdiff
path: root/sys/cmd/rc/parse.h
diff options
context:
space:
mode:
Diffstat (limited to 'sys/cmd/rc/parse.h')
-rw-r--r--sys/cmd/rc/parse.h78
1 files changed, 41 insertions, 37 deletions
diff --git a/sys/cmd/rc/parse.h b/sys/cmd/rc/parse.h
index 5955904..64ee07b 100644
--- a/sys/cmd/rc/parse.h
+++ b/sys/cmd/rc/parse.h
@@ -60,24 +60,26 @@ extern int yydebug;
Tif = 261, /* Tif */
Telse = 262, /* Telse */
Tswitch = 263, /* Tswitch */
- Ttwiddle = 264, /* Ttwiddle */
- Tbang = 265, /* Tbang */
- Tsubshell = 266, /* Tsubshell */
- Tfunc = 267, /* Tfunc */
- Tredir = 268, /* Tredir */
- Tdup = 269, /* Tdup */
- Tpipe = 270, /* Tpipe */
- Tindex = 271, /* Tindex */
- Tbasic = 272, /* Tbasic */
- Targs = 273, /* Targs */
- Tword = 274, /* Tword */
- Twords = 275, /* Twords */
- Tparen = 276, /* Tparen */
- Tblock = 277, /* Tblock */
- Tandand = 278, /* Tandand */
- Toror = 279, /* Toror */
- Tcount = 280, /* Tcount */
- Tjoin = 281 /* Tjoin */
+ Tcase = 264, /* Tcase */
+ Tcasebody = 265, /* Tcasebody */
+ Ttwiddle = 266, /* Ttwiddle */
+ Tbang = 267, /* Tbang */
+ Tsubshell = 268, /* Tsubshell */
+ Tfunc = 269, /* Tfunc */
+ Tredir = 270, /* Tredir */
+ Tdup = 271, /* Tdup */
+ Tpipe = 272, /* Tpipe */
+ Tindex = 273, /* Tindex */
+ Tbasic = 274, /* Tbasic */
+ Targs = 275, /* Targs */
+ Tword = 276, /* Tword */
+ Twords = 277, /* Twords */
+ Tparen = 278, /* Tparen */
+ Tblock = 279, /* Tblock */
+ Tandand = 280, /* Tandand */
+ Toror = 281, /* Toror */
+ Tcount = 282, /* Tcount */
+ Tjoin = 283 /* Tjoin */
};
typedef enum yytokentype yytoken_kind_t;
#endif
@@ -92,24 +94,26 @@ extern int yydebug;
#define Tif 261
#define Telse 262
#define Tswitch 263
-#define Ttwiddle 264
-#define Tbang 265
-#define Tsubshell 266
-#define Tfunc 267
-#define Tredir 268
-#define Tdup 269
-#define Tpipe 270
-#define Tindex 271
-#define Tbasic 272
-#define Targs 273
-#define Tword 274
-#define Twords 275
-#define Tparen 276
-#define Tblock 277
-#define Tandand 278
-#define Toror 279
-#define Tcount 280
-#define Tjoin 281
+#define Tcase 264
+#define Tcasebody 265
+#define Ttwiddle 266
+#define Tbang 267
+#define Tsubshell 268
+#define Tfunc 269
+#define Tredir 270
+#define Tdup 271
+#define Tpipe 272
+#define Tindex 273
+#define Tbasic 274
+#define Targs 275
+#define Tword 276
+#define Twords 277
+#define Tparen 278
+#define Tblock 279
+#define Tandand 280
+#define Toror 281
+#define Tcount 282
+#define Tjoin 283
/* Value type. */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
@@ -119,7 +123,7 @@ union YYSTYPE
struct Tree *tree;
-#line 123 "sys/cmd/rc/parse.h"
+#line 127 "sys/cmd/rc/parse.h"
};
typedef union YYSTYPE YYSTYPE;